A simple wrapper around Synology's synoacltool
==============================================

Python module to interact with ``synoacltool``, the CLI tool for
accessing Synology NAS proprietary ACL implementation.

The module is to be run on an actual Synology NAS itself. It can be
useful when scripting tasks that involve setting the ACLs.
